searchNodes=[{"ref":"Rabbit.Connection.html","title":"Rabbit.Connection","type":"behaviour","doc":"A RabbitMQ connection process. This wraps around the standard AMQP.Connection. It provides the following benefits: Durability during connection failures through use of expotential backoff. Subscriptions that assist connection status monitoring. Ability to create module-based connections that permit easy runtime setup through an init/1 callback. Example # This is a connection defmodule MyConnection do use Rabbit.Connection # Callbacks # Perform any runtime configuration def init(opts) do opts = Keyword.put(opts, :uri, System.get_env(&quot;RABBIT_URI&quot;)) {:ok, opts} end end # Start the connection MyConnection.start_link() # Subscribe to the connection MyConnection.subscribe() receive do {:connected, connection} -&gt; # Do stuff with AMQP.Connection end # Stop the connection MyConnection.stop() receive do {:disconnected, reason} -&gt; # Do stuff with disconnect end"},{"ref":"Rabbit.Connection.html#c:alive?/0","title":"Rabbit.Connection.alive?/0","type":"callback","doc":"Checks whether a connection is alive."},{"ref":"Rabbit.Connection.html#c:fetch/0","title":"Rabbit.Connection.fetch/0","type":"callback","doc":"Fetches the raw AMQP.Connection struct from the process."},{"ref":"Rabbit.Connection.html#c:init/1","title":"Rabbit.Connection.init/1","type":"callback","doc":""},{"ref":"Rabbit.Connection.html#c:start_link/1","title":"Rabbit.Connection.start_link/1","type":"callback","doc":"Starts a RabbitMQ connection process. Options :uri - The connection URI. This takes priority over other connection attributes. :username - The name of a user registered with the broker - defaults to &quot;guest&quot;. :password - The password of user - defaults to &quot;guest. :virtual_host - The name of a virtual host in the broker - defaults to &quot;/&quot;. :host - The hostname of the broker - defaults to &quot;localhost&quot;. :port - The port the broker is listening on - defaults to 5672. :channel_max - The channel_max handshake parameter - defaults to 0. :frame_max - The frame_max handshake parameter - defaults to 0. :heartbeat - The hearbeat interval in seconds - defaults to 10. :connection_timeout - The connection timeout in milliseconds - defaults to 50000. :ssl_options - Enable SSL by setting the location to cert files - defaults to :none. :client_properties - A list of extra client properties to be sent to the server - defaults to []. :socket_options - Extra socket options. These are appended to the default options. See http://www.erlang.org/doc/man/inet.html#setopts-2 and http://www.erlang.org/doc/man/gen_tcp.html#connect-4 for descriptions of the available options."},{"ref":"Rabbit.Connection.html#c:stop/0","title":"Rabbit.Connection.stop/0","type":"callback","doc":"Stops a RabbitMQ connection process."},{"ref":"Rabbit.Connection.html#c:subscribe/1","title":"Rabbit.Connection.subscribe/1","type":"callback","doc":"Subscribes a process to the RabbitMQ connection. A subscribed process can receive the following messages: {:connected, connection} - where connection is an AMQP.Connection struct. During the subscription process, if the connection is alive, this message will immediately be sent. If the connection goes down, and manages to reconnect, this message will be sent. {:disconnected, reason} - where reason can be any value. If the connection goes down, all subscribing processes are sent this message. The connection process will then go through an exponential backoff period until connection is achieved again."},{"ref":"Rabbit.Connection.html#t:option/0","title":"Rabbit.Connection.option/0","type":"type","doc":""},{"ref":"Rabbit.Connection.html#t:options/0","title":"Rabbit.Connection.options/0","type":"type","doc":""},{"ref":"Rabbit.Connection.html#t:t/0","title":"Rabbit.Connection.t/0","type":"type","doc":""},{"ref":"Rabbit.Connection.html#t:uri/0","title":"Rabbit.Connection.uri/0","type":"type","doc":""},{"ref":"Rabbit.Consumer.html","title":"Rabbit.Consumer","type":"behaviour","doc":"A RabbitMQ consumer process. This wraps around the standard AMQP.Channel. It provides the following benefits: Durability during connection and channel failures through use of expotential backoff. Ability to create module-based consumers that permit easy runtime setup through the init/1 and after_connect/2 callbacks. Automatic acknowledgements based on the return value of the handle_message/1 callback. Ability to handle exceptions through the handle_error/1 callback. Each message is executed within its own supervised task. Automatic payload decoding based on available serializers and message content type. Example # This is a connection defmodule MyConnection do use Rabbit.Connection end # This is a consumer defmodule MyConsumer do use Rabbit.Consumer # Callbacks # Perform any runtime configuration def init(opts) do {:ok, opts} end # Perform exchange or queue setup def after_connect(channel, queue) do AMQP.Queue.declare(channel, queue) :ok end # Handle consumed messages def handle_message(message) do {:ack, message} end # Handle errors that occur within handle_message/1 def handle_error(message) do {:nack, message} end end # Start the connection MyConnection.start_link() # Start the consumer MyConsumer.start_link(MyConnection, queue: &quot;my_queue&quot;, prefetch_count: 20) Serializers When a message is consumed, its content type is compared to the list of available serializers. If a serializer matches the content type, the message will be automatically decoded. You can find out more about serializers at Rabbit.Serializer."},{"ref":"Rabbit.Consumer.html#c:after_connect/2","title":"Rabbit.Consumer.after_connect/2","type":"callback","doc":"A callback executed after the channel is open, but before consumption. The callback is called with an AMQP.Channel, as well as the queue that will be consumed. At the most basic, you will most likely want to declare the queue to ensure its available. This will be entirely application dependent though. def after_connect(channel, queue) do AMQP.Queue.declare(channel, queue) :ok end The callback must return an :ok atom - otherise it will be marked as failed, and the consumer will attempt to go through the connection setup process again."},{"ref":"Rabbit.Consumer.html#c:handle_error/1","title":"Rabbit.Consumer.handle_error/1","type":"callback","doc":"A callback executed to handle message exceptions. If the original handle_message/1 callback raises an error, this callback will be called with the message - but with the :error_reason and :error_stack fields filled. You may choose to return the same values as handle_message/1."},{"ref":"Rabbit.Consumer.html#c:handle_message/1","title":"Rabbit.Consumer.handle_message/1","type":"callback","doc":"A callback executed to handle message consumption. The callback is called with a Rabbit.Message struct. You may find more information about the message structure within its own documentation. The message may be automatically decoded based on the content type and available serializers. You may choose to ack, nack, or reject the message based on the return value. {:ack, message} - will awknowledge the message. {:ack, message, options} - will awknowledge the message with options. {:nack, message} - will negative awknowledge the message. {:nack, message, options} - will negative awknowledge the message with options. {:reject, message} - will reject the message. {:reject, message, options} - will reject the message with options. If you dont return one of these values - nothing will be done."},{"ref":"Rabbit.Consumer.html#c:init/1","title":"Rabbit.Consumer.init/1","type":"callback","doc":"A callback executed when the consumer starts. The options passed represent the options that will be used by the consumer. This must return {:ok, keyword} or :ignore."},{"ref":"Rabbit.Consumer.html#c:start_link/2","title":"Rabbit.Consumer.start_link/2","type":"callback","doc":"Starts a RabbitMQ consumer process. Options :queue - The queue to consume messages from. :prefetch_count - The basic unit of concurrency for a given consumer - defaults to 0. :prefetch_size - The prefetch window size in octets - defaults to 0, meaning no specific limit. :consumer_tag - The identifier of the consumer. If empty, one will be generared by the server. :no_local - A boolean representing whether messages should not be sent to the same connection that published them - defaults to false. :no_ack - A boolean representing whether acknowledgements are not required for messages - defaults to false. :exclusive - A boolean representing whether only this consumer can access the queue - defaults to false. :no_wait - A boolean representing whether the server should not respond to methods - defaults to false. :arguments - A set of arguments for the consume."},{"ref":"Rabbit.Consumer.html#c:stop/0","title":"Rabbit.Consumer.stop/0","type":"callback","doc":"Stops a RabbitMQ consumer process."},{"ref":"Rabbit.Consumer.html#t:action_options/0","title":"Rabbit.Consumer.action_options/0","type":"type","doc":""},{"ref":"Rabbit.Consumer.html#t:delivery_tag/0","title":"Rabbit.Consumer.delivery_tag/0","type":"type","doc":""},{"ref":"Rabbit.Consumer.html#t:option/0","title":"Rabbit.Consumer.option/0","type":"type","doc":""},{"ref":"Rabbit.Consumer.html#t:options/0","title":"Rabbit.Consumer.options/0","type":"type","doc":""},{"ref":"Rabbit.Consumer.html#t:t/0","title":"Rabbit.Consumer.t/0","type":"type","doc":""},{"ref":"Rabbit.Message.html","title":"Rabbit.Message","type":"module","doc":"A message consumed by a Rabbit.Consumer. After starting a consumer, any message passed to the Rabbit.Consumer.handle_message/1 callback will be wrapped in a messsage struct. The struct has the following fields: :consumer - The PID of the consumer process. :module - The module of the consumer process. :channel - The AMQP.Channel being used by the consumer. :payload - The raw payload of the message. :decoded_payload - If the message has a content type - this will be the payload decoded using the applicable serializer. :meta - The metadata sent when publishing or set by the broker. :error_reason - The reason for any error that occurs during the message handling callback. :error_stack - The stacktrace that might accompany the error."},{"ref":"Rabbit.Message.html#new/5","title":"Rabbit.Message.new/5","type":"function","doc":"Creates a new message struct."},{"ref":"Rabbit.Message.html#t:t/0","title":"Rabbit.Message.t/0","type":"type","doc":""},{"ref":"Rabbit.Producer.html","title":"Rabbit.Producer","type":"behaviour","doc":"A RabbitMQ producer process. This wraps around the standard AMQP.Channel. It provides the following benefits: Durability during connection and channel failures through use of expotential backoff. Channel pooling for increased publishing performance. Ability to create module-based producers that permit easy runtime setup through an init/1 callback. Simplification of standard publishing options. Automatic payload encoding based on available serializers and message content type. Example # This is a connection defmodule MyConnection do use Rabbit.Connection end # This is a producer defmodule MyProducer do use Rabbit.Producer # Callbacks def init(opts) do # Perform any runtime configuration... {:ok, opts} end end # Start the connection MyConnection.start_link() # Start the producer MyProducer.start_link(MyConnection, publish_opts: [content_type: &quot;application/json&quot;]) # Publish a message MyProducer.publish(&quot;my_exchange&quot;, &quot;my_queue&quot;, %{foo: &quot;bar&quot;}) Serializers When a message is published, its content type is compared to the list of available serializers. If a serializer matches the content type, the message will be automatically encoded. You can find out more about serializers at Rabbit.Serializer."},{"ref":"Rabbit.Producer.html#c:init/1","title":"Rabbit.Producer.init/1","type":"callback","doc":""},{"ref":"Rabbit.Producer.html#c:publish/5","title":"Rabbit.Producer.publish/5","type":"callback","doc":""},{"ref":"Rabbit.Producer.html#c:start_link/2","title":"Rabbit.Producer.start_link/2","type":"callback","doc":"Starts a RabbitMQ producer process. Options :immediate - tocome.."},{"ref":"Rabbit.Producer.html#c:stop/0","title":"Rabbit.Producer.stop/0","type":"callback","doc":"Stops a RabbitMQ producer process."},{"ref":"Rabbit.Producer.html#t:exchange/0","title":"Rabbit.Producer.exchange/0","type":"type","doc":""},{"ref":"Rabbit.Producer.html#t:message/0","title":"Rabbit.Producer.message/0","type":"type","doc":""},{"ref":"Rabbit.Producer.html#t:publish_option/0","title":"Rabbit.Producer.publish_option/0","type":"type","doc":""},{"ref":"Rabbit.Producer.html#t:publish_options/0","title":"Rabbit.Producer.publish_options/0","type":"type","doc":""},{"ref":"Rabbit.Producer.html#t:routing_key/0","title":"Rabbit.Producer.routing_key/0","type":"type","doc":""},{"ref":"Rabbit.Producer.html#t:start_option/0","title":"Rabbit.Producer.start_option/0","type":"type","doc":""},{"ref":"Rabbit.Producer.html#t:start_options/0","title":"Rabbit.Producer.start_options/0","type":"type","doc":""},{"ref":"Rabbit.Producer.html#t:t/0","title":"Rabbit.Producer.t/0","type":"type","doc":""},{"ref":"Rabbit.Serializer.html","title":"Rabbit.Serializer","type":"behaviour","doc":"A behaviour to implement serializers. To create a serializer, you just need to implement the encode/1 and decode/1 callbacks, Example defmodule MySerializer do @behaviour Rabbit.Serializer @impl true def encode(data) do # Create a binary from data end @impl true def decode(binary) do # Create data from a binary end end Default Serializers By default, Rabbit comes with serializers for the following content types: &quot;application/erlang&quot; &quot;application/json&quot; - requires the Jason library to be added. You can modify the default serializers through application config: config :rabbit, serializers: %{ &quot;application/custom-type&quot; =&gt; MySerializer }"},{"ref":"Rabbit.Serializer.html#c:decode/1","title":"Rabbit.Serializer.decode/1","type":"callback","doc":"Callback invoked to decode the given binary to data."},{"ref":"Rabbit.Serializer.html#c:encode/1","title":"Rabbit.Serializer.encode/1","type":"callback","doc":"Callback invoked to encode the given data to a binary."},{"ref":"Rabbit.Serializer.html#t:t/0","title":"Rabbit.Serializer.t/0","type":"type","doc":""},{"ref":"readme.html","title":"Rabbit","type":"extras","doc":"Rabbit Rabbit is a set of tools for building applications with RabbitMQ."},{"ref":"readme.html#installation","title":"Rabbit - Installation","type":"extras","doc":"The package can be installed by adding rabbit to your list of dependencies in mix.exs: def deps do [ {:rabbit, &quot;~&gt; 0.1&quot;} ] end"},{"ref":"readme.html#documentation","title":"Rabbit - Documentation","type":"extras","doc":"Please see HexDocs for additional documentation."},{"ref":"readme.html#example","title":"Rabbit - Example","type":"extras","doc":"Create a connection module: defmodule MyConnection do use Rabbit.Connection # Callbacks # Perform runtime config def init(opts) do {:ok, opts} end end MyConnection.start_link() Create a consumer module: defmodule MyConsumer do use Rabbit.Consumer # Callbacks # Perform runtime config def init(opts) do {:ok, opts} end # Perform any exchange or queue setup def after_connect(channel, queue) do AMQP.Queue.declare(channel, queue) :ok end # Handle message consumption def handle_message(message) do IO.inspect(message.payload) {:ack, message} end # Handle message errors def handle_error(message) do {:nack, message} end end MyConsumer.start_link(MyConnection, queue: &quot;my_queue&quot;, prefetch_count: 10) Create a producer module: defmodule MyProducer do use Rabbit.Producer # Callbacks # Perform runtime config def init(opts) do {:ok, opts} end end MyProducer.start_link(MyConnection) MyProducer.publish(&quot;&quot;, &quot;my_queue&quot;, &quot;hello&quot;)"}]